
.. DO NOT EDIT.
.. THIS FILE WAS AUTOMATICALLY GENERATED BY SPHINX-GALLERY.
.. TO MAKE CHANGES, EDIT THE SOURCE PYTHON FILE:
.. "_as_gen/run_sph_basic_disc.py"
.. LINE NUMBERS ARE GIVEN BELOW.

.. only:: html

    .. note::
        :class: sphx-glr-download-link-note

        :ref:`Go to the end <sphx_glr_download__as_gen_run_sph_basic_disc.py>`
        to download the full example code.

.. rst-class:: sphx-glr-example-title

.. _sphx_glr__as_gen_run_sph_basic_disc.py:


Basic disc simulation
========================

This simple example shows how to run a basic disc simulation in SPH

.. GENERATED FROM PYTHON SOURCE LINES 7-16

.. code-block:: Python
   :lineno-start: 8


    import shamrock

    # If we use the shamrock executable to run this script instead of the python interpreter,
    # we should not initialize the system as the shamrock executable needs to handle specific MPI logic
    if not shamrock.sys.is_initialized():
        shamrock.change_loglevel(1)
        shamrock.sys.init("0:0")








.. GENERATED FROM PYTHON SOURCE LINES 17-18

Setup units

.. GENERATED FROM PYTHON SOURCE LINES 18-30

.. code-block:: Python
   :lineno-start: 19


    si = shamrock.UnitSystem()
    sicte = shamrock.Constants(si)
    codeu = shamrock.UnitSystem(
        unit_time=3600 * 24 * 365,
        unit_length=sicte.au(),
        unit_mass=sicte.sol_mass(),
    )
    ucte = shamrock.Constants(codeu)
    G = ucte.G()









.. GENERATED FROM PYTHON SOURCE LINES 31-32

List parameters

.. GENERATED FROM PYTHON SOURCE LINES 32-78

.. code-block:: Python
   :lineno-start: 33


    # Resolution
    Npart = 1000000

    # Sink parameters
    center_mass = 1
    center_racc = 0.1

    # Disc parameter
    disc_mass = 0.01  # sol mass
    rout = 10  # au
    rin = 1  # au
    H_r_in = 0.05
    q = 0.5
    p = 3.0 / 2.0
    r0 = 1

    # Viscosity parameter
    alpha_AV = 1e-3 / 0.08
    alpha_u = 1
    beta_AV = 2

    # Integrator parameters
    C_cour = 0.3
    C_force = 0.25


    # Disc profiles
    def sigma_profile(r):
        sigma_0 = 1
        return sigma_0 * (r / rin) ** (-p)


    def kep_profile(r):
        return (G * center_mass / r) ** 0.5


    def omega_k(r):
        return kep_profile(r) / r


    def cs_profile(r):
        cs_in = (H_r_in * rin) * omega_k(rin)
        return ((r / rin) ** (-q)) * cs_in









.. GENERATED FROM PYTHON SOURCE LINES 79-80

Utility functions and quantities deduced from the base one

.. GENERATED FROM PYTHON SOURCE LINES 80-100

.. code-block:: Python
   :lineno-start: 81


    # Deduced quantities
    pmass = disc_mass / Npart
    bmin = (-rout * 2, -rout * 2, -rout * 2)
    bmax = (rout * 2, rout * 2, rout * 2)

    cs0 = cs_profile(rin)


    def rot_profile(r):
        return ((kep_profile(r) ** 2) - (2 * p + q) * cs_profile(r) ** 2) ** 0.5


    def H_profile(r):
        H = cs_profile(r) / omega_k(r)
        # fact = (2.**0.5) * 3. # factor taken from phantom, to fasten thermalizing
        fact = 1
        return fact * H









.. GENERATED FROM PYTHON SOURCE LINES 101-104

Start the context
The context holds the data of the code
We then init the layout of the field (e.g. the list of fields used by the solver)

.. GENERATED FROM PYTHON SOURCE LINES 104-108

.. code-block:: Python
   :lineno-start: 105


    ctx = shamrock.Context()
    ctx.pdata_layout_new()








.. GENERATED FROM PYTHON SOURCE LINES 109-110

Attach a SPH model to the data and configure it

.. GENERATED FROM PYTHON SOURCE LINES 110-139

.. code-block:: Python
   :lineno-start: 111


    model = shamrock.get_Model_SPH(context=ctx, vector_type="f64_3", sph_kernel="M4")

    # Generate the default config
    cfg = model.gen_default_config()
    # Use disc alpha model viscosity
    cfg.set_artif_viscosity_ConstantDisc(alpha_u=alpha_u, alpha_AV=alpha_AV, beta_AV=beta_AV)
    # use the Lodato Price 2007 equation of state
    cfg.set_eos_locally_isothermalLP07(cs0=cs0, q=q, r0=r0)
    # Use the given code units
    cfg.set_units(codeu)
    # Change particle mass
    cfg.set_particle_mass(pmass)
    # Set the CFL
    cfg.set_cfl_cour(C_cour)
    cfg.set_cfl_force(C_force)

    # Set the solver config to be the one stored in cfg
    model.set_solver_config(cfg)

    # Print the solver config
    model.get_current_config().print_status()

    # We want the patches to split above 10^8 part and merge if smaller than 1 part (e.g. disable patch)
    model.init_scheduler(int(1e8), 1)

    # Set the simulation box size
    model.resize_simulation_box(bmin, bmax)





.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    ----- SPH Solver configuration ----- 
    units :  
    unit_length      : 149597870700 
    unit_mass        : 1.98847e+30 
    unit_current     : 1 
    unit_temperature : 1 
    unit_qte         : 1 
    unit_lumint      : 1 
    part mass 1e-08 ( can be changed using .set_part_mass() ) 
    cfl force 0.25 
    cfl courant 0.3 
    --- artificial viscosity config 
      Config Type : constant disc 
      alpha_AV   = 0.0125 
      alpha_u     = 1 
      beta_AV     = 2 
    --- artificial viscosity config (deduced) 
    ------------- 
    EOS config f64_3 : 
    locally isothermal (Lodato Price 2007) :  
    --- Bondaries config 
      Config Type : Free boundaries 
    --- Bondaries config config (deduced) 
    ------------- 
    ------------------------------------ 




.. GENERATED FROM PYTHON SOURCE LINES 140-141

Add the sink particle

.. GENERATED FROM PYTHON SOURCE LINES 141-145

.. code-block:: Python
   :lineno-start: 142


    # null position and velocity
    model.add_sink(center_mass, (0, 0, 0), (0, 0, 0), center_racc)








.. GENERATED FROM PYTHON SOURCE LINES 146-147

Create the setup

.. GENERATED FROM PYTHON SOURCE LINES 147-164

.. code-block:: Python
   :lineno-start: 148


    setup = model.get_setup()
    gen_disc = setup.make_generator_disc_mc(
        part_mass=pmass,
        disc_mass=disc_mass,
        r_in=rin,
        r_out=rout,
        sigma_profile=sigma_profile,
        H_profile=H_profile,
        rot_profile=rot_profile,
        cs_profile=cs_profile,
        random_seed=666,
    )

    # Print the dot graph of the setup
    print(gen_disc.get_dot())





.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    digraph G {
    rankdir=LR;
    node_0 [label="GeneratorMCDisc"];
    node_2 [label="Simulation"];
    node_0 -> node_2;
    }





.. GENERATED FROM PYTHON SOURCE LINES 165-166

Apply the setup

.. GENERATED FROM PYTHON SOURCE LINES 166-168

.. code-block:: Python
   :lineno-start: 166

    setup.apply_setup(gen_disc)





.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    Info: pushing data in scheduler, N = 1000000                          [DataInserterUtility][rank=0] 
    Info: reattributing data ...                                          [DataInserterUtility][rank=0] 
    Info: reattributing data done in  46.08 ms                            [DataInserterUtility][rank=0] 
    Info: run scheduler step ...                                          [DataInserterUtility][rank=0] 
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 20.92 us   (59.8%)  
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 1000000 min = 1000000                      [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 1000000 min = 1000000                 [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 1000000
        max = 1000000
        avg = 1000000
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1082.00 ns (0.2%)
       patch tree reduce : 1112.00 ns (0.2%)
       gen split merge   : 772.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 912.00 ns  (0.2%)
       LB compute        : 471.23 us  (98.0%)
       LB move op cnt    : 0
       LB apply          : 2.19 us    (0.5%)  
    Info: the setup took : 3.1029427800000002 s                                     [SPH setup][rank=0] 




.. GENERATED FROM PYTHON SOURCE LINES 169-176

Run a single step to init the integrator and smoothing lenght of the particles
Here the htolerance is the maximum factor of evolution of the smoothing lenght in each
Smoothing lenght iterations, increasing it affect the performance negatively but increse the
convergence rate of the smoothing lenght
this is why we increase it temporely to 1.3 before lowering it back to 1.1 (default value)
Note that both ``change_htolerance`` can be removed and it will work the same but would converge
more slowly at the first timestep

.. GENERATED FROM PYTHON SOURCE LINES 176-181

.. code-block:: Python
   :lineno-start: 177


    model.change_htolerance(1.3)
    model.timestep()
    model.change_htolerance(1.1)





.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    ---------------- t = 0, dt = 0 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 1000000 min = 1000000                      [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 1000000 min = 1000000                 [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 1000000
        max = 1000000
        avg = 1000000
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 28.82 us   (2.4%)
       patch tree reduce : 2.15 us    (0.2%)
       gen split merge   : 922.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 1012.00 ns (0.1%)
       LB compute        : 1168.03 us (95.6%)
       LB move op cnt    : 0
       LB apply          : 2.17 us    (0.2%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.07 us    (69.0%)  
    Info: free boundaries skipping geometry update                            [PositionUpdated][rank=0] 
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.7251187699241748 unconverged cnt = 999992   
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.7251187699241738 unconverged cnt = 999954   
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.7529481567236117 unconverged cnt = 999847   
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.7529481567236117 unconverged cnt = 999058   
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.7529481567236117 unconverged cnt = 970419   
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.7529481567236117 unconverged cnt = 623188   
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.7529481567236117 unconverged cnt = 38585   
    Warning: smoothing length is not converged, rerunning the iterator ...    [Smoothinglength][rank=0]
         largest h = 0.7529481567236117 unconverged cnt = 101   
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 0, max = 8.951768789337238e-07
      iterations = 3  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (9.877002876193511e-06,-3.3153642116852934e-05,0)
        sum a = (-3.3203691532368573e-18,1.3145951341386741e-18,4.658681209898652e-21)
        sum e = 0.05004044613227274
        sum de = 3.3881317890172014e-20  
    Info: cfl dt = 3.895385803115442e-05 cfl multiplier : 0.01                     [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    3.4999e+04    |     1000000 |   2.857e+01   |    0 % |   0 % |  950.66 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 0 (tsim/hr)                                             [sph::Model][rank=0] 




.. GENERATED FROM PYTHON SOURCE LINES 182-185

Manipulating the simulation
------------------------
Dump files (path relative to where you have started shamrock)

.. GENERATED FROM PYTHON SOURCE LINES 185-201

.. code-block:: Python
   :lineno-start: 186


    dump_folder = "_to_trash"
    import os

    os.system("mkdir -p " + dump_folder)

    # VTK dump
    model.do_vtk_dump(dump_folder + "/init_disc.vtk", True)

    # Shamrock restart dump files
    model.dump(dump_folder + "/init_disc.sham")

    # Phantom dump
    dump = model.make_phantom_dump()
    dump.save_dump(dump_folder + "/init_disc.phdump")





.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    Info: dump to _to_trash/init_disc.vtk                                            [VTK Dump][rank=0]
                  - took 193.56 ms, bandwidth = 275.92 MB/s  
    Info: Dumping state to _to_trash/init_disc.sham                                       [SPH][rank=0] 
    Info: dump to _to_trash/init_disc.sham                                      [Shamrock Dump][rank=0]
                  - took 111.68 ms, bandwidth = 1.00 GB/s  




.. GENERATED FROM PYTHON SOURCE LINES 202-203

Single timestep

.. GENERATED FROM PYTHON SOURCE LINES 203-205

.. code-block:: Python
   :lineno-start: 203

    model.evolve_once()





.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    ---------------- t = 0, dt = 3.895385803115442e-05 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 1000000 min = 1000000                      [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 1000000 min = 1000000                 [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 1000000
        max = 1000000
        avg = 1000000
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 13.43 us   (1.5%)
       patch tree reduce : 1754.00 ns (0.2%)
       gen split merge   : 661.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 922.00 ns  (0.1%)
       LB compute        : 848.85 us  (95.0%)
       LB move op cnt    : 0
       LB apply          : 2.10 us    (0.2%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.98 us    (74.8%)  
    Info: free boundaries skipping geometry update                            [PositionUpdated][rank=0] 
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 9.801209890616902e-15, max = 9.999977929357478e-07
      iterations = 1  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (9.877274458998799e-06,-3.315172351500661e-05,4.5064286673134777e-11)
        sum a = (9.639234939753938e-19,-2.7511630126819675e-18,-5.734413052911613e-19)
        sum e = 0.05004044727231212
        sum de = 1.638590127723689e-07  
    Info: cfl dt = 0.0013246034089634724 cfl multiplier : 0.34                     [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.6707e+05    |     1000000 |   5.986e+00   |    0 % |   0 % |  950.66 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 0.02342891502810307 (tsim/hr)                           [sph::Model][rank=0] 
    Info: iteration since start : 2                                                       [SPH][rank=0] 
    Info: time since start : 56.800032086 (s)                                             [SPH][rank=0] 




.. GENERATED FROM PYTHON SOURCE LINES 206-207

Evolve until a given time (code units)

.. GENERATED FROM PYTHON SOURCE LINES 207-209

.. code-block:: Python
   :lineno-start: 207

    model.evolve_until(0.001)





.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    ---------------- t = 3.895385803115442e-05, dt = 0.0009610461419688457 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 1000000 min = 1000000                      [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 1000000 min = 1000000                 [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 1000000
        max = 1000000
        avg = 1000000
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 14.07 us   (1.6%)
       patch tree reduce : 1974.00 ns (0.2%)
       gen split merge   : 691.00 ns  (0.1%)
       split / merge op  : 0/0
       apply split merge : 1062.00 ns (0.1%)
       LB compute        : 831.43 us  (95.3%)
       LB move op cnt    : 0
       LB apply          : 2.00 us    (0.2%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 2.83 us    (76.4%)  
    Info: free boundaries skipping geometry update                            [PositionUpdated][rank=0] 
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 5.761597459766956e-14, max = 9.99984119568859e-07
      iterations = 2  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (9.883695796318215e-06,-3.310631048745232e-05,1.1117989573418118e-09)
        sum a = (-1.4670610646444482e-18,4.743384504624082e-19,-5.713237229230256e-19)
        sum e = 0.050041140179747985
        sum de = 4.202179861575134e-06  
    Info: cfl dt = 0.002188797630762785 cfl multiplier : 0.56                      [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.5980e+05    |     1000000 |   6.258e+00   |    0 % |   0 % |  950.66 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 0.5528584899305022 (tsim/hr)                            [sph::Model][rank=0] 
    Info: iteration since start : 3                                                       [SPH][rank=0] 
    Info: time since start : 63.270718495000004 (s)                                       [SPH][rank=0] 

    True



.. GENERATED FROM PYTHON SOURCE LINES 210-211

Get the sinks positions

.. GENERATED FROM PYTHON SOURCE LINES 211-213

.. code-block:: Python
   :lineno-start: 211

    print(model.get_sinks())





.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    [{'pos': (-6.9645029304530114e-12, -4.9250231245437725e-11, -1.15686324401464e-12), 'velocity': (-1.374628895941851e-08, -9.842692059825167e-08, -2.3137247314062144e-09), 'sph_acceleration': (-1.3548784354595216e-05, -9.834742672125893e-05, -2.313722832390366e-06), 'ext_acceleration': (0.0, 0.0, 0.0), 'mass': 1.0, 'angular_momentum': (0.0, 0.0, 0.0), 'accretion_radius': 0.1}]




.. GENERATED FROM PYTHON SOURCE LINES 214-216

Get the fields as python dictionary of numpy arrays


.. GENERATED FROM PYTHON SOURCE LINES 218-221

.. warning::
    Do not do this on a large distributed simulation as this gather all data on MPI rank 0
    and will use a lot of memory (and crash if the simulation is too large)

.. GENERATED FROM PYTHON SOURCE LINES 221-223

.. code-block:: Python
   :lineno-start: 221

    print(ctx.collect_data())





.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    adding ->  xyz
    adding ->  vxyz
    adding ->  axyz
    adding ->  axyz_ext
    adding ->  hpart
    adding ->  uint
    adding ->  duint
    {'xyz': array([[-7.65869663, -6.39642264, -0.95720382],
           [-7.55994716, -6.50503632, -1.17167965],
           [-7.51908014, -6.42069667, -1.15259445],
           ...,
           [ 7.55443246,  6.37259864,  1.01837507],
           [ 7.57542343,  6.28326045,  1.24366222],
           [ 7.65988442,  6.31067776,  0.96346951]]), 'vxyz': array([[ 1.26064246e+00, -1.52288302e+00, -5.51013538e-04],
           [ 1.28544857e+00, -1.51257386e+00, -6.24111362e-03],
           [ 1.28734769e+00, -1.52178147e+00, -3.34366897e-03],
           ...,
           [-1.27700796e+00,  1.52214753e+00,  3.96807363e-03],
           [-1.26813654e+00,  1.53456934e+00,  6.37018776e-03],
           [-1.25652339e+00,  1.53414415e+00,  4.88137129e-03]]), 'axyz': array([[ -7.62410459,  -3.72392315,  -0.55169954],
           [ -5.34944275, -11.84317988,  -6.24085762],
           [ -3.35111101,  -9.6642787 ,  -3.34390459],
           ...,
           [  4.82957121,   1.96547374,   3.96824979],
           [  3.67155219,   0.58009335,   6.36994852],
           [  4.92884225,   2.37259344,   4.88141652]]), 'axyz_ext': array([[ 0.299749  ,  0.25034564,  0.03746341],
           [ 0.29432289,  0.25325323,  0.04561568],
           [ 0.30052408,  0.25662367,  0.04606712],
           ...,
           [-0.3036538 , -0.25614946, -0.04093404],
           [-0.30590699, -0.25372751, -0.05022095],
           [-0.30459947, -0.25094754, -0.03831289]]), 'hpart': array([0.20772107, 0.24976708, 0.20235783, ..., 0.22745153, 0.30584271,
           0.22650431]), 'uint': array([-2.25966937e-05,  1.34453304e-05, -2.26322647e-05, ...,
           -6.17869819e-05, -4.00023136e-05, -6.15569252e-05]), 'duint': array([-0.04227789, -0.0562385 , -0.10388435, ..., -0.07490322,
           -0.05237283, -0.07313985])}




.. GENERATED FROM PYTHON SOURCE LINES 224-225

Performing a timestep loop

.. GENERATED FROM PYTHON SOURCE LINES 225-237

.. code-block:: Python
   :lineno-start: 225

    dt_stop = 0.001
    for i in range(10):
        t_target = i * dt_stop
        # skip if the model is already past the target
        if model.get_time() > t_target:
            continue

        model.evolve_until(i * dt_stop)

        # Dump name is "dump_xxxx.sham" where xxxx is the timestep
        model.dump(dump_folder + f"/dump_{i:04}.sham")





.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    Info: iteration since start : 3                                                       [SPH][rank=0] 
    Info: time since start : 64.267555328 (s)                                             [SPH][rank=0] 
    Info: Dumping state to _to_trash/dump_0001.sham                                       [SPH][rank=0] 
    Info: dump to _to_trash/dump_0001.sham                                      [Shamrock Dump][rank=0]
                  - took 112.67 ms, bandwidth = 1015.75 MB/s  
    ---------------- t = 0.001, dt = 0.001 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 1000000 min = 1000000                      [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 1000000 min = 1000000                 [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 1000000
        max = 1000000
        avg = 1000000
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 15.06 us   (2.8%)
       patch tree reduce : 1162.00 ns (0.2%)
       gen split merge   : 1133.00 ns (0.2%)
       split / merge op  : 0/0
       apply split merge : 1332.00 ns (0.3%)
       LB compute        : 492.74 us  (93.2%)
       LB move op cnt    : 0
       LB apply          : 1934.00 ns (0.4%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1713.00 ns (69.0%)  
    Info: free boundaries skipping geometry update                            [PositionUpdated][rank=0] 
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 1.9971047123763135e-14, max = 9.999648722707607e-07
      iterations = 2  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (9.883777268369466e-06,-3.310446840349008e-05,1.156861416194528e-09)
        sum a = (-8.673617379884035e-19,9.486769009248164e-20,3.2610768469290563e-19)
        sum e = 0.05004120231976796
        sum de = 8.405289991465789e-06  
    Info: cfl dt = 0.0027765192383187257 cfl multiplier : 0.7066666666666667       [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.5898e+05    |     1000000 |   6.290e+00   |    0 % |   0 % |  950.66 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 0.5723439934925735 (tsim/hr)                            [sph::Model][rank=0] 
    Info: iteration since start : 4                                                       [SPH][rank=0] 
    Info: time since start : 70.684281555 (s)                                             [SPH][rank=0] 
    Info: Dumping state to _to_trash/dump_0002.sham                                       [SPH][rank=0] 
    Info: dump to _to_trash/dump_0002.sham                                      [Shamrock Dump][rank=0]
                  - took 111.62 ms, bandwidth = 1.00 GB/s  
    ---------------- t = 0.002, dt = 0.001 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 1000000 min = 1000000                      [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 1000000 min = 1000000                 [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 1000000
        max = 1000000
        avg = 1000000
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 6.65 us    (1.6%)
       patch tree reduce : 1162.00 ns (0.3%)
       gen split merge   : 802.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 1092.00 ns (0.3%)
       LB compute        : 411.17 us  (95.9%)
       LB move op cnt    : 0
       LB apply          : 1854.00 ns (0.4%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1643.00 ns (72.9%)  
    Info: free boundaries skipping geometry update                            [PositionUpdated][rank=0] 
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 6.151207595751965e-14, max = 9.999926494822936e-07
      iterations = 2  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (9.883580477933292e-06,-3.310454869572145e-05,1.1568559320233846e-09)
        sum a = (-4.777265822514254e-19,2.5343225781848666e-18,-6.441685563868954e-19)
        sum e = 0.050041210663350086
        sum de = 1.2608707797471775e-05  
    Info: cfl dt = 0.0031848710647867013 cfl multiplier : 0.8044444444444444       [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.6484e+05    |     1000000 |   6.066e+00   |    0 % |   0 % |  950.66 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 0.593428177465404 (tsim/hr)                             [sph::Model][rank=0] 
    Info: iteration since start : 5                                                       [SPH][rank=0] 
    Info: time since start : 76.880886207 (s)                                             [SPH][rank=0] 
    Info: Dumping state to _to_trash/dump_0003.sham                                       [SPH][rank=0] 
    Info: dump to _to_trash/dump_0003.sham                                      [Shamrock Dump][rank=0]
                  - took 123.84 ms, bandwidth = 924.12 MB/s  
    ---------------- t = 0.003, dt = 0.001 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 1000000 min = 1000000                      [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 1000000 min = 1000000                 [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 1000000
        max = 1000000
        avg = 1000000
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 6.60 us    (1.5%)
       patch tree reduce : 1423.00 ns (0.3%)
       gen split merge   : 781.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 1372.00 ns (0.3%)
       LB compute        : 426.14 us  (95.9%)
       LB move op cnt    : 0
       LB apply          : 1863.00 ns (0.4%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1804.00 ns (70.6%)  
    Info: free boundaries skipping geometry update                            [PositionUpdated][rank=0] 
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 4.0130451842052e-14, max = 9.999844335031671e-07
      iterations = 2  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (9.883384418489218e-06,-3.310462979684227e-05,1.156846806790515e-09)
        sum a = (5.6022759131399424e-18,1.5856456772600502e-18,-2.625802136488331e-20)
        sum e = 0.05004122228128194
        sum de = 1.681219206056172e-05  
    Info: cfl dt = 0.00347680926460198 cfl multiplier : 0.8696296296296296         [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.6594e+05    |     1000000 |   6.026e+00   |    0 % |   0 % |  950.66 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 0.5973664001105727 (tsim/hr)                            [sph::Model][rank=0] 
    Info: iteration since start : 6                                                       [SPH][rank=0] 
    Info: time since start : 83.044304982 (s)                                             [SPH][rank=0] 
    Info: Dumping state to _to_trash/dump_0004.sham                                       [SPH][rank=0] 
    Info: dump to _to_trash/dump_0004.sham                                      [Shamrock Dump][rank=0]
                  - took 112.46 ms, bandwidth = 1017.62 MB/s  
    ---------------- t = 0.004, dt = 0.001 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 1000000 min = 1000000                      [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 1000000 min = 1000000                 [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 1000000
        max = 1000000
        avg = 1000000
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 6.37 us    (1.5%)
       patch tree reduce : 1062.00 ns (0.2%)
       gen split merge   : 812.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 1242.00 ns (0.3%)
       LB compute        : 413.99 us  (96.1%)
       LB move op cnt    : 0
       LB apply          : 1883.00 ns (0.4%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1764.00 ns (67.7%)  
    Info: free boundaries skipping geometry update                            [PositionUpdated][rank=0] 
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 4.6709809818100174e-14, max = 9.999956170277897e-07
      iterations = 2  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (9.883189093216266e-06,-3.310471170215324e-05,1.156834046054849e-09)
        sum a = (2.2124500582282325e-18,-1.2197274440461925e-19,-1.8592373192231892e-19)
        sum e = 0.05004123716236742
        sum de = 2.1015717680430067e-05  
    Info: cfl dt = 0.0036933730598545473 cfl multiplier : 0.9130864197530864       [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.6526e+05    |     1000000 |   6.051e+00   |    0 % |   0 % |  950.66 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 0.5949371622890636 (tsim/hr)                            [sph::Model][rank=0] 
    Info: iteration since start : 7                                                       [SPH][rank=0] 
    Info: time since start : 89.22274115500001 (s)                                        [SPH][rank=0] 
    Info: Dumping state to _to_trash/dump_0005.sham                                       [SPH][rank=0] 
    Info: dump to _to_trash/dump_0005.sham                                      [Shamrock Dump][rank=0]
                  - took 118.44 ms, bandwidth = 966.32 MB/s  
    ---------------- t = 0.005, dt = 0.001 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 1000000 min = 1000000                      [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 1000000 min = 1000000                 [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 1000000
        max = 1000000
        avg = 1000000
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 6.54 us    (1.5%)
       patch tree reduce : 1142.00 ns (0.3%)
       gen split merge   : 802.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 1062.00 ns (0.2%)
       LB compute        : 418.06 us  (96.0%)
       LB move op cnt    : 0
       LB apply          : 1844.00 ns (0.4%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1712.00 ns (67.0%)  
    Info: free boundaries skipping geometry update                            [PositionUpdated][rank=0] 
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 1.8592711866765938e-13, max = 9.999947606502062e-07
      iterations = 3  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (9.882994505261276e-06,-3.3104794406937104e-05,1.1568176487832544e-09)
        sum a = (2.537710709973884e-18,4.0657581468206416e-20,-1.4907779871675686e-19)
        sum e = 0.05004125532426453
        sum de = 2.5219238580460913e-05  
    Info: cfl dt = 0.003861256985531854 cfl multiplier : 0.9420576131687243        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.6458e+05    |     1000000 |   6.076e+00   |    0 % |   0 % |  950.66 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 0.5925014722056892 (tsim/hr)                            [sph::Model][rank=0] 
    Info: iteration since start : 8                                                       [SPH][rank=0] 
    Info: time since start : 95.432639381 (s)                                             [SPH][rank=0] 
    Info: Dumping state to _to_trash/dump_0006.sham                                       [SPH][rank=0] 
    Info: dump to _to_trash/dump_0006.sham                                      [Shamrock Dump][rank=0]
                  - took 113.99 ms, bandwidth = 1004.03 MB/s  
    ---------------- t = 0.006, dt = 0.001 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 1000000 min = 1000000                      [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 1000000 min = 1000000                 [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 1000000
        max = 1000000
        avg = 1000000
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 6.63 us    (1.5%)
       patch tree reduce : 1052.00 ns (0.2%)
       gen split merge   : 831.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 1362.00 ns (0.3%)
       LB compute        : 423.41 us  (96.0%)
       LB move op cnt    : 0
       LB apply          : 1834.00 ns (0.4%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1723.00 ns (68.8%)  
    Info: free boundaries skipping geometry update                            [PositionUpdated][rank=0] 
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 2.8407185226364647e-14, max = 9.99983084205644e-07
      iterations = 3  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (9.882800657757216e-06,-3.310487790646313e-05,1.1567976082859543e-09)
        sum a = (-1.1011428314305904e-19,-1.0299920638612292e-18,3.2017845406212553e-19)
        sum e = 0.05004127679554002
        sum de = 2.9422695190993687e-05  
    Info: cfl dt = 0.003997801820065854 cfl multiplier : 0.9613717421124829        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.6315e+05    |     1000000 |   6.129e+00   |    0 % |   0 % |  950.66 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 0.5873471848659896 (tsim/hr)                            [sph::Model][rank=0] 
    Info: iteration since start : 9                                                       [SPH][rank=0] 
    Info: time since start : 101.69210428400001 (s)                                       [SPH][rank=0] 
    Info: Dumping state to _to_trash/dump_0007.sham                                       [SPH][rank=0] 
    Info: dump to _to_trash/dump_0007.sham                                      [Shamrock Dump][rank=0]
                  - took 113.45 ms, bandwidth = 1008.82 MB/s  
    ---------------- t = 0.007, dt = 0.001 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 1000000 min = 1000000                      [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 1000000 min = 1000000                 [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 1000000
        max = 1000000
        avg = 1000000
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 7.09 us    (1.6%)
       patch tree reduce : 1153.00 ns (0.3%)
       gen split merge   : 872.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 1062.00 ns (0.2%)
       LB compute        : 425.99 us  (95.8%)
       LB move op cnt    : 0
       LB apply          : 2.01 us    (0.5%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1763.00 ns (70.7%)  
    Info: free boundaries skipping geometry update                            [PositionUpdated][rank=0] 
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 6.671860683196617e-13, max = 9.99998293967359e-07
      iterations = 3  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (9.882607553815906e-06,-3.31049621960066e-05,1.1567739127542622e-09)
        sum a = (8.436448154652831e-19,-3.2526065174565133e-19,5.61159327555974e-19)
        sum e = 0.050041301612790835
        sum de = 3.3626020256162476e-05  
    Info: cfl dt = 0.004072662849661999 cfl multiplier : 0.9742478280749886        [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.6189e+05    |     1000000 |   6.177e+00   |    0 % |   0 % |  950.66 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 0.5828150684604416 (tsim/hr)                            [sph::Model][rank=0] 
    Info: iteration since start : 10                                                      [SPH][rank=0] 
    Info: time since start : 107.996687433 (s)                                            [SPH][rank=0] 
    Info: Dumping state to _to_trash/dump_0008.sham                                       [SPH][rank=0] 
    Info: dump to _to_trash/dump_0008.sham                                      [Shamrock Dump][rank=0]
                  - took 114.91 ms, bandwidth = 995.95 MB/s  
    ---------------- t = 0.008, dt = 0.0010000000000000009 ---------------- 
    Info: summary :                                                               [LoadBalance][rank=0] 
    Info:  - strategy "psweep" : max = 1000000 min = 1000000                      [LoadBalance][rank=0] 
    Info:  - strategy "round robin" : max = 1000000 min = 1000000                 [LoadBalance][rank=0] 
    Info: Loadbalance stats :                                                     [LoadBalance][rank=0]
        npatch = 1
        min = 1000000
        max = 1000000
        avg = 1000000
        efficiency = 100.00%  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 6.88 us    (1.7%)
       patch tree reduce : 1092.00 ns (0.3%)
       gen split merge   : 811.00 ns  (0.2%)
       split / merge op  : 0/0
       apply split merge : 962.00 ns  (0.2%)
       LB compute        : 397.04 us  (95.7%)
       LB move op cnt    : 0
       LB apply          : 2.17 us    (0.5%)  
    Info: Scheduler step timings :                                                  [Scheduler][rank=0]
       metadata sync     : 1753.00 ns (66.0%)  
    Info: free boundaries skipping geometry update                            [PositionUpdated][rank=0] 
    Info: smoothing length iteration converged                                [Smoothinglength][rank=0]
      eps min = 6.472671188767377e-13, max = 9.99993968642381e-07
      iterations = 3  
    Info: conservation infos :                                                     [sph::Model][rank=0]
        sum v = (9.88241519651721e-06,-3.3105047270816766e-05,1.156746546048336e-09)
        sum a = (5.077115485842276e-18,9.351243737687476e-19,5.27278009665802e-19)
        sum e = 0.050041329818688036
        sum de = 3.7829142459172544e-05  
    Info: cfl dt = 0.0038805384262170063 cfl multiplier : 0.9828318853833258       [sph::Model][rank=0] 
    Info: processing rate infos :                                                  [sph::Model][rank=0]
    ---------------------------------------------------------------------------------------
    | rank |  rate  (N.s^-1)  |     Nobj    | t compute (s) | interf | alloc |  mem (max) |
    ---------------------------------------------------------------------------------------
    | 0    |    1.5977e+05    |     1000000 |   6.259e+00   |    0 % |   0 % |  950.66 MB |
    ---------------------------------------------------------------------------------------  
    Info: estimated rate : 0.5751892449907079 (tsim/hr)                            [sph::Model][rank=0] 
    Info: iteration since start : 11                                                      [SPH][rank=0] 
    Info: time since start : 114.38442726800001 (s)                                       [SPH][rank=0] 
    Info: Dumping state to _to_trash/dump_0009.sham                                       [SPH][rank=0] 
    Info: dump to _to_trash/dump_0009.sham                                      [Shamrock Dump][rank=0]
                  - took 114.98 ms, bandwidth = 995.35 MB/s  




.. GENERATED FROM PYTHON SOURCE LINES 238-239

Plot column integrated density

.. GENERATED FROM PYTHON SOURCE LINES 239-275

.. code-block:: Python
   :lineno-start: 239

    import matplotlib.pyplot as plt

    pixel_x = 1200
    pixel_y = 1080
    radius = 5
    center = (0.0, 0.0, 0.0)

    aspect = pixel_x / pixel_y
    pic_range = [-radius * aspect, radius * aspect, -radius, radius]
    delta_x = (radius * 2 * aspect, 0.0, 0.0)
    delta_y = (0.0, radius * 2, 0.0)

    arr_rho = model.render_cartesian_column_integ(
        "rho", "f64", center=(0.0, 0.0, 0.0), delta_x=delta_x, delta_y=delta_y, nx=pixel_x, ny=pixel_y
    )

    import copy

    import matplotlib

    my_cmap = copy.copy(matplotlib.colormaps.get_cmap("gist_heat"))  # copy the default cmap
    my_cmap.set_bad(color="black")

    fig_width = 6
    fig_height = fig_width / aspect
    plt.figure(figsize=(fig_width, fig_height))
    res = plt.imshow(arr_rho, cmap=my_cmap, origin="lower", extent=pic_range, norm="log", vmin=1e-9)

    cbar = plt.colorbar(res, extend="both")
    cbar.set_label(r"$\int \rho \, \mathrm{d} z$ [code unit]")
    # or r"$\rho$ [code unit]" for slices

    plt.title("t = {:0.3f} [code unit]".format(model.get_time()))
    plt.xlabel("x")
    plt.ylabel("z")
    plt.show()



.. image-sg:: /_as_gen/images/sphx_glr_run_sph_basic_disc_001.png
   :alt: t = 0.009 [code unit]
   :srcset: /_as_gen/images/sphx_glr_run_sph_basic_disc_001.png
   :class: sphx-glr-single-img


.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    Info: compute_column_integ field_name: rho, center: (0,0,0), delta_x: (11.11111111111111,0,0), delta_y: (0,10,0), nx: 1200, ny: 1080  [sph::CartesianRender][rank=0] 
    Info: compute_column_integ took 11.26 s                              [sph::CartesianRender][rank=0] 





.. rst-class:: sphx-glr-timing

   **Total running time of the script:** (1 minutes 49.179 seconds)

**Estimated memory usage:**  1179 MB


.. _sphx_glr_download__as_gen_run_sph_basic_disc.py:

.. only:: html

  .. container:: sphx-glr-footer sphx-glr-footer-example

    .. container:: sphx-glr-download sphx-glr-download-jupyter

      :download:`Download Jupyter notebook: run_sph_basic_disc.ipynb <run_sph_basic_disc.ipynb>`

    .. container:: sphx-glr-download sphx-glr-download-python

      :download:`Download Python source code: run_sph_basic_disc.py <run_sph_basic_disc.py>`

    .. container:: sphx-glr-download sphx-glr-download-zip

      :download:`Download zipped: run_sph_basic_disc.zip <run_sph_basic_disc.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
